/*=========================================================================

  Program:   Visualization Toolkit
  Module:    $RCSfile: vtkImageLineActor.cxx,v $

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "vtkImageLineActor.h"
#include "vtkProperty2D.h"
#include "vtkMapper2D.h"
#include "vtkActor2D.h"
#include "vtkObjectFactory.h"

vtkCxxRevisionMacro(vtkImageLineActor, "$Revision: 1.1 $");
vtkStandardNewMacro(vtkImageLineActor);

vtkCxxSetObjectMacro(vtkImageLineActor,Property, vtkProperty2D);

vtkImageLineActor::vtkImageLineActor()
{
  this->Property = (vtkProperty2D*) NULL;

  this->Point1Coordinate = vtkCoordinate::New();
  this->Point1Coordinate->SetCoordinateSystemToWorld();

  this->Point2Coordinate = vtkCoordinate::New();
  this->Point2Coordinate->SetCoordinateSystemToWorld();
}

// Destroy an actor2D.
vtkImageLineActor::~vtkImageLineActor()
{
  if (this->Property)
    {
    this->Property->UnRegister(this);
    this->Property = NULL;
    }
  if (this->Point1Coordinate)
    {
    this->Point1Coordinate->Delete();
    this->Point1Coordinate = NULL;
    }
  if (this->Point2Coordinate)
    {
    this->Point2Coordinate->Delete();
    this->Point2Coordinate = NULL;
    }
}

void vtkImageLineActor::SetInput(vtkImageData *)
{
}

void vtkImageLineActor::ReleaseGraphicsResources(vtkWindow *win)
{
  // pass this information onto the mapper
  if (this->Mapper)
    {
    this->Mapper->ReleaseGraphicsResources(win);
    }
}

// Renders an actor2D's property and then it's mapper.
int vtkImageLineActor::RenderOverlay(vtkViewport* viewport)
{
  vtkDebugMacro(<< "vtkImageLineActor::RenderOverlay");

  if (!this->Property)
    {
    vtkDebugMacro(<< "vtkImageLineActor::Render - Creating Property2D");
    // Force creation of default property
    this->GetProperty();
    }

  this->Property->Render(viewport);

  if (!this->Mapper) 
    {
    vtkErrorMacro(<< "vtkImageLineActor::Render - No mapper set");
    return 0;
    }

//  this->Mapper->RenderOverlay(viewport, this); 

  return 1;
}

// Renders an actor2D's property and then it's mapper.
int vtkImageLineActor::RenderOpaqueGeometry(vtkViewport* viewport)
{
  vtkDebugMacro(<< "vtkImageLineActor::RenderOpaqueGeometry");

  if (!this->Property)
    {
    vtkDebugMacro(<< "vtkImageLineActor::Render - Creating Property2D");
    // Force creation of default property
    this->GetProperty();
    }

  this->Property->Render(viewport);

  if (!this->Mapper) 
    {
    vtkErrorMacro(<< "vtkImageLineActor::Render - No mapper set");
    return 0;
    }

//  this->Mapper->RenderOpaqueGeometry(viewport, this);

  return 1;
}

// Renders an actor2D's property and then it's mapper.
int vtkImageLineActor::RenderTranslucentGeometry(vtkViewport* viewport)
{
  vtkDebugMacro(<< "vtkImageLineActor::RenderTranslucentGeometry");

  if (!this->Property)
    {
    vtkDebugMacro(<< "vtkImageLineActor::Render - Creating Property2D");
    // Force creation of default property
    this->GetProperty();
    }

  this->Property->Render(viewport);

  if (!this->Mapper) 
    {
    vtkErrorMacro(<< "vtkImageLineActor::Render - No mapper set");
    return 0;
    }

//  this->Mapper->RenderTranslucentGeometry(viewport, this);

  return 1;
}



unsigned long int vtkImageLineActor::GetMTime()
{
  unsigned long mTime=this->Superclass::GetMTime();
  unsigned long time;

  time  = this->Point1Coordinate->GetMTime();
  mTime = ( time > mTime ? time : mTime );
  time  = this->Point2Coordinate->GetMTime();
  mTime = ( time > mTime ? time : mTime );

  if ( this->Property != NULL )
    {
    time = this->Property->GetMTime();
    mTime = ( time > mTime ? time : mTime );
    }

  return mTime;
}



 
// Returns an Prop2D's property2D.  Creates a property if one
// doesn't already exist.
vtkProperty2D *vtkImageLineActor::GetProperty()
{
  if (this->Property == NULL)
    {
    this->Property = vtkProperty2D::New();
    this->Property->Register(this);
    this->Property->Delete();
    this->Modified();
    }
  return this->Property;
}

void vtkImageLineActor::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os,indent);

  os << indent << "Point Coordinate: " 
     << this->Point1Coordinate << "\n";
  this->Point1Coordinate->PrintSelf(os, indent.GetNextIndent());

  os << indent << "Point2 Coordinate: " 
     << this->Point2Coordinate << "\n";
  this->Point2Coordinate->PrintSelf(os, indent.GetNextIndent());

  os << indent << "Property: " << this->Property << "\n";
  if (this->Property)
    {
    this->Property->PrintSelf(os, indent.GetNextIndent());
    }
}

